==> rubberband-1.9.2.tar.bz2: rubberband-1.9.2/src/audiocurves/SpectralDifferenceAudioCurve.h <==
/* -*- c-basic-offset: 4 indent-tabs-mode: nil -*-  vi:set ts=8 sts=4 sw=4: */

/*
    Rubber Band Library
    An audio time-stretching and pitch-shifting library.
    Copyright 2007-2021 Particular Programs Ltd.

    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License as
    published by the Free Software Foundation; either version 2 of the
    License, or (at your option) any later version.  See the file
    COPYING included with this distribution for more information.

    Alternatively, if you have a valid commercial licence for the
    Rubber Band Library obtained by agreement with the copyright
    holders, you may redistribute and/or modify it under the terms
    described in that licence.

    If you wish to distribute code using the Rubber Band Library
    under terms other than those of the GNU General Public License,
    you must obtain a valid commercial licence before doing so.
*/

#ifndef RUBBERBAND_SPECTRALDIFFERENCE_AUDIO_CURVE_H
#define RUBBERBAND_SPECTRALDIFFERENCE_AUDIO_CURVE_H

#include "dsp/AudioCurveCalculator.h"
#include "dsp/Window.h"

namespace RubberBand
{

class SpectralDifferenceAudioCurve : public AudioCurveCalculator
{
public:
    SpectralDifferenceAudioCurve(Parameters parameters);

    virtual ~SpectralDifferenceAudioCurve();

    virtual void setFftSize(int newSize);

    virtual float processFloat(const float *R__ mag, int increment);
    virtual double processDouble(const double *R__ mag, int increment);
    virtual void reset();
    virtual const char *getUnit() const { return "V"; }

protected:
    double *R__ m_mag;
    double *R__ m_tmpbuf;
};

}

#endif

==> rubberband_2.0.0.orig.tar.bz2: rubberband-2.0.0/src/audiocurves/SpectralDifferenceAudioCurve.h <==
/* -*- c-basic-offset: 4 indent-tabs-mode: nil -*-  vi:set ts=8 sts=4 sw=4: */

/*
    Rubber Band Library
    An audio time-stretching and pitch-shifting library.
    Copyright 2007-2021 Particular Programs Ltd.

    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License as
    published by the Free Software Foundation; either version 2 of the
    License, or (at your option) any later version.  See the file
    COPYING included with this distribution for more information.

    Alternatively, if you have a valid commercial licence for the
    Rubber Band Library obtained by agreement with the copyright
    holders, you may redistribute and/or modify it under the terms
    described in that licence.

    If you wish to distribute code using the Rubber Band Library
    under terms other than those of the GNU General Public License,
    you must obtain a valid commercial licence before doing so.
*/

#ifndef RUBBERBAND_SPECTRALDIFFERENCE_AUDIO_CURVE_H
#define RUBBERBAND_SPECTRALDIFFERENCE_AUDIO_CURVE_H

#include "../dsp/AudioCurveCalculator.h"
#include "../dsp/Window.h"

namespace RubberBand
{

class SpectralDifferenceAudioCurve : public AudioCurveCalculator
{
public:
    SpectralDifferenceAudioCurve(Parameters parameters);

    virtual ~SpectralDifferenceAudioCurve();

    virtual void setFftSize(int newSize);

    virtual float processFloat(const float *R__ mag, int increment);
    virtual double processDouble(const double *R__ mag, int increment);
    virtual void reset();
    virtual const char *getUnit() const { return "V"; }

protected:
    double *R__ m_mag;
    double *R__ m_tmpbuf;
};

}

#endif
